Other commands
=====================================

Other utils commands.

.. click:: web_novel_scraper.__main__:clean_files
    :prog: clean-files
    :nested: full

.. click:: web_novel_scraper.__main__:show_novel_dir
    :prog: show-novel-dir
    :nested: full

.. click:: web_novel_scraper.__main__:version
    :prog: version
    :nested: full